[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [44616] trunk/blender/source: style cleanup - spelling corrections & update some incorrect comments.

Campbell Barton ideasman42 at gmail.com
Sat Mar 3 12:45:08 CET 2012


Revision: 44616
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=44616
Author:   campbellbarton
Date:     2012-03-03 11:45:08 +0000 (Sat, 03 Mar 2012)
Log Message:
-----------
style cleanup - spelling corrections & update some incorrect comments.

Modified Paths:
--------------
    trunk/blender/source/blender/blenkernel/intern/anim.c
    trunk/blender/source/blender/blenkernel/intern/anim_sys.c
    trunk/blender/source/blender/blenkernel/intern/image.c
    trunk/blender/source/blender/blenkernel/intern/mball.c
    trunk/blender/source/blender/blenkernel/intern/mesh.c
    trunk/blender/source/blender/blenkernel/intern/softbody.c
    trunk/blender/source/blender/bmesh/bmesh_operator_api.h
    trunk/blender/source/blender/bmesh/intern/bmesh_core.c
    trunk/blender/source/blender/bmesh/intern/bmesh_operators.c
    trunk/blender/source/blender/bmesh/intern/bmesh_polygon.c
    trunk/blender/source/blender/bmesh/intern/bmesh_walkers.h
    trunk/blender/source/blender/bmesh/operators/bmo_edgesplit.c
    trunk/blender/source/blender/editors/animation/anim_filter.c
    trunk/blender/source/blender/editors/animation/drivers.c
    trunk/blender/source/blender/editors/animation/keyframing.c
    trunk/blender/source/blender/editors/armature/editarmature.c
    trunk/blender/source/blender/editors/include/BIF_gl.h
    trunk/blender/source/blender/editors/interface/interface_templates.c
    trunk/blender/source/blender/editors/interface/view2d_ops.c
    trunk/blender/source/blender/editors/mesh/bmesh_utils.c
    trunk/blender/source/blender/editors/render/render_opengl.c
    trunk/blender/source/blender/editors/screen/screen_edit.c
    trunk/blender/source/blender/editors/sculpt_paint/paint_vertex.c
    trunk/blender/source/blender/editors/space_outliner/outliner_edit.c
    trunk/blender/source/blender/editors/space_sequencer/sequencer_add.c
    trunk/blender/source/blender/editors/space_view3d/drawobject.c
    trunk/blender/source/blender/editors/space_view3d/view3d_draw.c
    trunk/blender/source/blender/editors/space_view3d/view3d_edit.c
    trunk/blender/source/blender/makesdna/DNA_anim_types.h
    trunk/blender/source/blender/makesdna/DNA_brush_types.h
    trunk/blender/source/blender/makesdna/DNA_fileglobal_types.h
    trunk/blender/source/blender/makesrna/RNA_types.h
    trunk/blender/source/blender/python/intern/bpy_props.c
    trunk/blender/source/creator/creator.c
    trunk/blender/source/gameengine/Expressions/PyObjectPlus.h
    trunk/blender/source/gameengine/Ketsji/KX_CameraActuator.cpp
    trunk/blender/source/gameengine/Ketsji/KX_CameraActuator.h
    trunk/blender/source/gameengine/Ketsji/KX_PythonSeq.cpp
    trunk/blender/source/gameengine/VideoTexture/ImageBuff.cpp
    trunk/blender/source/tools/spell_check_source.py
    trunk/blender/source/tools/spell_check_source_config.py

Modified: trunk/blender/source/blender/blenkernel/intern/anim.c
===================================================================
--- trunk/blender/source/blender/blenkernel/intern/anim.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/anim.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -453,7 +453,7 @@
 
 /* free curve path data 
  * NOTE: frees the path itself!
- * NOTE: this is increasingly innacurate with non-uniform BevPoint subdivisions [#24633]
+ * NOTE: this is increasingly inaccurate with non-uniform BevPoint subdivisions [#24633]
  */
 void free_path(Path *path)
 {

Modified: trunk/blender/source/blender/blenkernel/intern/anim_sys.c
===================================================================
--- trunk/blender/source/blender/blenkernel/intern/image.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/image.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -1834,7 +1834,7 @@
 		break;
 	}
 	
-	/* dont use notifiers because they are not 100% sure to succseed
+	/* dont use notifiers because they are not 100% sure to succeeded
 	 * this also makes sure all scenes are accounted for. */
 	{
 		Scene *scene;

Modified: trunk/blender/source/blender/blenkernel/intern/mball.c
===================================================================
--- trunk/blender/source/blender/blenkernel/intern/mball.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/mball.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -1753,7 +1753,7 @@
 					}
 
 					/* create "new" bb, only point 0 and 6, which are
-					 * neccesary for octal tree filling */
+					 * necessary for octal tree filling */
 					mainb[a]->bb->vec[0][0] = min_x - ml->rad;
 					mainb[a]->bb->vec[0][1] = min_y - ml->rad;
 					mainb[a]->bb->vec[0][2] = min_z - ml->rad;

Modified: trunk/blender/source/blender/blenkernel/intern/mesh.c
===================================================================
--- trunk/blender/source/blender/blenkernel/intern/mesh.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/mesh.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -2192,7 +2192,7 @@
                            CustomData *ldata, CustomData *pdata,
                            MVert *mvert, int totface, int UNUSED(totloop),
                            int totpoly,
-                           /* when teseelating to recalcilate normals after
+                           /* when tessellating to recalcilate normals after
                             * we can skip copying here */
                            const int do_face_nor_cpy)
 {

Modified: trunk/blender/source/blender/blenkernel/intern/softbody.c
===================================================================
--- trunk/blender/source/blender/blenkernel/intern/softbody.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/softbody.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -3289,7 +3289,7 @@
 
 			get_scalar_from_vertexgroup(ob, a,(short) (sb->vertgroup-1), &bp->goal);
 			/* do this always, regardless successfull read from vertex group */
-			/* this is where '2.5 every thing is animateable' goes wrong in the first place jow_go_for2_5 */
+			/* this is where '2.5 every thing is animatable' goes wrong in the first place jow_go_for2_5 */
 			/* 1st coding action to take : move this to frame level */
 			/* reads: leave the bp->goal as it was read from vertex group / or default .. we will need it at per frame call */
 			/* should be fixed for meshes */
@@ -3585,7 +3585,7 @@
 		if (nu->bezt) {
 			/* bezier case ; this is nicly said naive; who ever wrote this part, it was not me (JOW) :) */
 			/* a: never ever make tangent handles (sub) and or (ob)ject to collision */
-			/* b: rather calculate them using some C2 (C2= continous in second derivate -> no jump in bending ) condition */
+			/* b: rather calculate them using some C2 (C2= continuous in second derivate -> no jump in bending ) condition */
 			/* not too hard to do, but needs some more code to care for;  some one may want look at it  JOW 2010/06/12*/
 			for (bezt=nu->bezt, a=0; a<nu->pntsu; a++, bezt++, bp+=3, curindex+=3) {
 				if (setgoal) {

Modified: trunk/blender/source/blender/bmesh/bmesh_operator_api.h
===================================================================
--- trunk/blender/source/blender/bmesh/bmesh_operator_api.h	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/bmesh/bmesh_operator_api.h	2012-03-03 11:45:08 UTC (rev 44616)
@@ -35,7 +35,7 @@
 
 #include <stdarg.h>
 
-/*
+/**
  * operators represent logical, executable mesh modules.  all topological
  * operations involving a bmesh has to go through them.
  *
@@ -55,18 +55,22 @@
  * bmesh_opdefines.c and the BMOpDefine struct for how to define new operators.
  *
  * in general, operators are fed arrays of elements, created using either
- * BM_HeaderFlag_To_Slot or BM_Flag_To_Slot (or through one of the format
- * specifyers in BMO_op_callf or BMO_op_initf).  Note that multiple element
- * types (e.g. faces and edges) can be fed to the same slot array.  Operators
- * act on this data, and possibly spit out data into output slots.
+ * #BMO_slot_buffer_from_hflag or #BMO_slot_buffer_from_flag
+ * (or through one of the format specifiers in #BMO_op_callf or #BMO_op_initf).
  *
- * some notes:
- * - operators should never read from header flags (e.g. element->head.flag). for
- *   example, if you want an operator to only operate on selected faces, you
- *   should use BM_HeaderFlag_To_Slot to put the selected elements into a slot.
- * - when you read from an element slot array or mapping, you can either tool-flag
- *   all the elements in it, or read them using an iterator APi (which is
- *   semantically similar to the iterator api in bmesh_iterators.h).
+ * \note multiple element types (e.g. faces and edges)
+ * can be fed to the same slot array.  Operators act on this data,
+ * and possibly spit out data into output slots.
+ *
+ * \note operators should never read from header flags (e.g. element->head.flag).
+ * For example, if you want an operator to only operate on selected faces, you
+ * should use #BMO_slot_buffer_from_hflag to put the selected elements into a slot.
+ *
+ * \note when you read from an element slot array or mapping, you can either tool-flag
+ * all the elements in it, or read them using an iterator API (which is semantically
+ * similar to the iterator api in bmesh_iterators.h).
+ *
+ * \note only #BMLoop items can't be put into slots as with verts, edges & faces.
  */
 
 struct GHashIterator;

Modified: trunk/blender/source/blender/bmesh/intern/bmesh_core.c
===================================================================
--- trunk/blender/source/blender/bmesh/intern/bmesh_core.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/bmesh/intern/bmesh_core.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -649,7 +649,7 @@
  * \brief Loop Reverse
  *
  * Changes the winding order of a face from CW to CCW or vice versa.
- * This euler is a bit peculiar in compairson to others as it is its
+ * This euler is a bit peculiar in comparison to others as it is its
  * own inverse.
  *
  * BMESH_TODO: reinsert validation code.
@@ -1096,7 +1096,7 @@
  * level wrapping functions (when holes are fully implemented, anyway).
  *
  * \note that holes represents which holes goes to the new face, and of
- * course this requires removing them from the exitsing face first, since
+ * course this requires removing them from the existing face first, since
  * you cannot have linked list links inside multiple lists.
  *
  * \return A BMFace pointer

Modified: trunk/blender/source/blender/bmesh/intern/bmesh_operators.c
===================================================================
--- trunk/blender/source/blender/bmesh/intern/bmesh_operators.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/bmesh/intern/bmesh_operators.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -679,7 +679,7 @@
  * into a slot for an operator.
  */
 void BMO_slot_buffer_from_hflag(BMesh *bm, BMOperator *op, const char *slotname,
-                         const char hflag, const char htype)
+                                const char hflag, const char htype)
 {
 	BMIter elements;
 	BMElem *ele;

Modified: trunk/blender/source/blender/bmesh/intern/bmesh_polygon.c
===================================================================
--- trunk/blender/source/blender/bmesh/intern/bmesh_polygon.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/bmesh/intern/bmesh_polygon.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -707,7 +707,7 @@
  *
  * Used by tesselator to find
  * the next triangle to 'clip off'
- * of a polygon while tesselating.
+ * of a polygon while tessellating.
  */
 static BMLoop *find_ear(BMesh *UNUSED(bm), BMFace *f, float (*verts)[3], const int nvert)
 {

Modified: trunk/blender/source/blender/bmesh/intern/bmesh_walkers.h
===================================================================
--- trunk/blender/source/blender/bmesh/intern/bmesh_walkers.h	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/bmesh/intern/bmesh_walkers.h	2012-03-03 11:45:08 UTC (rev 44616)
@@ -103,7 +103,7 @@

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
--- trunk/blender/source/blender/blenkernel/intern/anim_sys.c	2012-03-03 02:47:01 UTC (rev 44615)
+++ trunk/blender/source/blender/blenkernel/intern/anim_sys.c	2012-03-03 11:45:08 UTC (rev 44616)
@@ -1589,14 +1589,14 @@
 		/* get path, remapped as appropriate to work in its new environment */
 	/* free_path= */ /* UNUSED */ animsys_remap_path(strip->remap, fcu->rna_path, &path);
 	
 		/* a valid property must be available, and it must be animateable */
 	if (RNA_path_resolve(ptr, path, &new_ptr, &prop) == 0) {
 		if (G.f & G_DEBUG) printf("NLA Strip Eval: Cannot resolve path \n");
 		return NULL;
 	}
 		/* only ok if animateable */
 	else if (RNA_property_animateable(&new_ptr, prop) == 0) {
-		if (G.f & G_DEBUG) printf("NLA Strip Eval: Property not animateable \n");
+		if (G.f & G_DEBUG) printf("NLA Strip Eval: Property not animatable \n");
 		return NULL;
 	}
 	
@@ -1589,14 +1589,14 @@
 	/* free_path= */ /* UNUSED */ animsys_remap_path(strip->remap, fcu->rna_path, &path);
 	
-		/* a valid property must be available, and it must be animateable */
+		/* a valid property must be available, and it must be animatable */
 	if (RNA_path_resolve(ptr, path, &new_ptr, &prop) == 0) {
 		if (G.f & G_DEBUG) printf("NLA Strip Eval: Cannot resolve path \n");
@@ -1589,14 +1589,14 @@
 		return NULL;
 	}
-		/* only ok if animateable */
+		/* only ok if animatable */
 	else if (RNA_property_animateable(&new_ptr, prop) == 0) {

Modified: trunk/blender/source/blender/blenkernel/intern/image.c
===================================================================